@@ -6,9 +6,18 @@
 Exception definitions for L{twisted.web}.
 """
 
-import operator, warnings
+from __future__ import division, absolute_import
 
-from twisted.web import http
+__all__ = [
+    'Error', 'PageRedirect', 'InfiniteRedirection', 'RenderError',
+    'MissingRenderMethod', 'MissingTemplateLoader', 'UnexposedMethodError',
+    'UnfilledSlot', 'UnsupportedType', 'FlattenerError',
+    'RedirectWithNoLocation',
+    ]
+
+from collections import Sequence
+
+from twisted.web._responses import RESPONSES
 
 
 class Error(Exception):
@@ -16,12 +25,12 @@ class Error(Exception):
     A basic HTTP error.
 
     @type status: C{str}
-    @ivar status: Refers to an HTTP status code, for example L{http.NOT_FOUND}.
+    @ivar status: Refers to an HTTP status code, for example C{http.NOT_FOUND}.
 
     @type message: C{str}
     @param message: A short error message, for example "NOT FOUND".
 
-    @type response: C{str}
+    @type response: C{bytes}
     @ivar response: A complete HTML document for an error page.
     """
     def __init__(self, code, message=None, response=None):
@@ -30,18 +39,18 @@ class Error(Exception):
 
         @type code: C{str}
         @param code: Refers to an HTTP status code, for example
-            L{http.NOT_FOUND}. If no C{message} is given, C{code} is mapped to a
-            descriptive string that is used instead.
+            C{http.NOT_FOUND}. If no C{message} is given, C{code} is mapped to a
+            descriptive bytestring that is used instead.
 
         @type message: C{str}
         @param message: A short error message, for example "NOT FOUND".
 
-        @type response: C{str}
+        @type response: C{bytes}
         @param response: A complete HTML document for an error page.
         """
         if not message:
             try:
-                message = http.responses.get(int(code))
+                message = RESPONSES.get(int(code))
             except ValueError:
                 # If code wasn't a stringified int, can't map the
                 # status code to a descriptive string so keep message
@@ -55,7 +64,7 @@ class Error(Exception):
 
 
     def __str__(self):
-        return '%s %s' % (self[0], self[1])
+        return '%s %s' % (self.status, self.message)
 
 
 
@@ -72,7 +81,7 @@ class PageRedirect(Error):
 
         @type code: C{str}
         @param code: Refers to an HTTP status code, for example
-            L{http.NOT_FOUND}. If no C{message} is given, C{code} is mapped to a
+            C{http.NOT_FOUND}. If no C{message} is given, C{code} is mapped to a
             descriptive string that is used instead.
 
         @type message: C{str}
@@ -88,7 +97,7 @@ class PageRedirect(Error):
         """
         if not message:
             try:
-                message = http.responses.get(int(code))
+                message = RESPONSES.get(int(code))
             except ValueError:
                 # If code wasn't a stringified int, can't map the
                 # status code to a descriptive string so keep message
@@ -117,7 +126,7 @@ class InfiniteRedirection(Error):
 
         @type code: C{str}
         @param code: Refers to an HTTP status code, for example
-            L{http.NOT_FOUND}. If no C{message} is given, C{code} is mapped to a
+            C{http.NOT_FOUND}. If no C{message} is given, C{code} is mapped to a
             descriptive string that is used instead.
 
         @type message: C{str}
@@ -133,7 +142,7 @@ class InfiniteRedirection(Error):
         """
         if not message:
             try:
-                message = http.responses.get(int(code))
+                message = RESPONSES.get(int(code))
             except ValueError:
                 # If code wasn't a stringified int, can't map the
                 # status code to a descriptive string so keep message
@@ -148,11 +157,42 @@ class InfiniteRedirection(Error):
 
 
 
+class RedirectWithNoLocation(Error):
+    """
+    Exception passed to L{ResponseFailed} if we got a redirect without a
+    C{Location} header field.
+
+    @since: 11.1
+    """
+
+    def __init__(self, code, message, uri):
+        """
+        Initializes a page redirect exception when no location is given.
+
+        @type code: C{str}
+        @param code: Refers to an HTTP status code, for example
+            C{http.NOT_FOUND}. If no C{message} is given, C{code} is mapped to
+            a descriptive string that is used instead.
+
+        @type message: C{str}
+        @param message: A short error message.
+
+        @type uri: C{str}
+        @param uri: The URI which failed to give a proper location header
+            field.
+        """
+        message = "%s to %s" % (message, uri)
+
+        Error.__init__(self, code, message)
+        self.uri = uri
+
+
+
 class UnsupportedMethod(Exception):
     """
     Raised by a resource when faced with a strange request method.
 
-    RFC 2616 (HTTP 1.1) gives us two choices when faced with this situtation:
+    RFC 2616 (HTTP 1.1) gives us two choices when faced with this situation:
     If the type of request is known to us, but not allowed for the requested
     resource, respond with NOT_ALLOWED.  Otherwise, if the request is something
     we don't know how to deal with in any case, respond with NOT_IMPLEMENTED.
@@ -170,11 +210,10 @@ class UnsupportedMethod(Exception):
         Exception.__init__(self, allowedMethods, *args)
         self.allowedMethods = allowedMethods
 
-        if not operator.isSequenceType(allowedMethods):
-            why = "but my first argument is not a sequence."
-            s = ("First argument must be a sequence of"
-                 " supported methods, %s" % (why,))
-            raise TypeError, s
+        if not isinstance(allowedMethods, Sequence):
+            raise TypeError(
+                "First argument must be a sequence of supported methods, "
+                "but my first argument is not a sequence.")
 
 
 
@@ -185,47 +224,6 @@ class SchemeNotSupported(Exception):
 
 
 
-from twisted.web import resource as _resource
-
-class ErrorPage(_resource.ErrorPage):
-    """
-    Deprecated alias for L{twisted.web.resource.ErrorPage}.
-    """
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            "twisted.web.error.ErrorPage is deprecated since Twisted 9.0.  "
-            "See twisted.web.resource.ErrorPage.", DeprecationWarning,
-            stacklevel=2)
-        _resource.ErrorPage.__init__(self, *args, **kwargs)
-
-
-
-class NoResource(_resource.NoResource):
-    """
-    Deprecated alias for L{twisted.web.resource.NoResource}.
-    """
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            "twisted.web.error.NoResource is deprecated since Twisted 9.0.  "
-            "See twisted.web.resource.NoResource.", DeprecationWarning,
-            stacklevel=2)
-        _resource.NoResource.__init__(self, *args, **kwargs)
-
-
-
-class ForbiddenResource(_resource.ForbiddenResource):
-    """
-    Deprecated alias for L{twisted.web.resource.ForbiddenResource}.
-    """
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            "twisted.web.error.ForbiddenResource is deprecated since Twisted "
-            "9.0.  See twisted.web.resource.ForbiddenResource.",
-            DeprecationWarning, stacklevel=2)
-        _resource.ForbiddenResource.__init__(self, *args, **kwargs)
-
-
-
 class RenderError(Exception):
     """
     Base exception class for all errors which can occur during template
@@ -380,12 +378,3 @@ class FlattenerError(Exception):
 
     def __str__(self):
         return repr(self)
-
-
-
-__all__ = [
-    'Error', 'PageRedirect', 'InfiniteRedirection', 'ErrorPage', 'NoResource',
-    'ForbiddenResource', 'RenderError', 'MissingRenderMethod',
-    'MissingTemplateLoader', 'UnexposedMethodError', 'UnfilledSlot',
-    'UnsupportedType', 'FlattenerError'
-]
